@@ -161,5 +161,5 @@ L<Data::Localize>
     CPAN ID: MAROS
     maros [at] k-1.com
     
-    L<http://www.revdev.at>
+    L<http://www.k-1.com>
 
