@@ -184,4 +184,4 @@ L<Unicode::Collate>
     CPAN ID: MAROS
     maros [at] k-1.com
     
-    L<http://www.revdev.at>
\ No newline at end of file
+    L<http://www.k-1.com>
\ No newline at end of file
