@@ -250,4 +250,4 @@ Helper method to check for a valid locale
     CPAN ID: MAROS
     maros [at] k-1.com
     
-    L<http://www.revdev.at>
\ No newline at end of file
+    L<http://www.k-1.com>
\ No newline at end of file
