@@ -59,4 +59,4 @@ L<Catalyst::Respone>
     CPAN ID: MAROS
     maros [at] k-1.com
     
-    L<http://www.revdev.at>
+    L<http://www.k-1.com>
