@@ -202,4 +202,4 @@ and L<Catalyst::View::TT>
     CPAN ID: MAROS
     maros [at] k-1.com
     
-    L<http://www.revdev.at>
+    L<http://www.k-1.com>
